==> lxqt-panel_0.15.0.orig.tar.xz: lxqt-panel-0.15.0/plugin-taskbar/translations/taskbar_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>LXQtTaskBar</name>
    <message>
        <location filename="../lxqttaskbar.cpp" line="650"/>
        <source>Activate task %1</source>
        <translation>Запустить задачу %1</translation>
    </message>
</context>
<context>
    <name>LXQtTaskButton</name>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="576"/>
        <source>Application</source>
        <translation>Приложение</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="610"/>
        <source>To &amp;Desktop</source>
        <translation>&amp;На рабочий стол</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="612"/>
        <source>&amp;All Desktops</source>
        <translation>&amp;Все рабочие столы</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="620"/>
        <source>Desktop &amp;%1</source>
        <translation>Рабочий стол &amp;%1</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="627"/>
        <source>&amp;To Current Desktop</source>
        <translation>На &amp;текущий рабочий стол</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="635"/>
        <source>&amp;Move</source>
        <translation>Пере&amp;местить</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="638"/>
        <source>Resi&amp;ze</source>
        <translation>Изм&amp;енить размер</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="645"/>
        <source>Ma&amp;ximize</source>
        <translation>Р&amp;азвернуть</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="652"/>
        <source>Maximize vertically</source>
        <translation>Развернуть по вертикали</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="657"/>
        <source>Maximize horizontally</source>
        <translation>Развернуть по горизонтали</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="663"/>
        <source>&amp;Restore</source>
        <translation>&amp;Восстановить</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="667"/>
        <source>Mi&amp;nimize</source>
        <translation>&amp;Свернуть</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="673"/>
        <source>Roll down</source>
        <translation>Развернуть из заголовока</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="679"/>
        <source>Roll up</source>
        <translation>Свернуть в заголовок</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="687"/>
        <source>&amp;Layer</source>
        <translation>&amp;Положение</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="689"/>
        <source>Always on &amp;top</source>
        <translation>Всегда на&amp;верху</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="695"/>
        <source>&amp;Normal</source>
        <translation>&amp;Обычное</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="701"/>
        <source>Always on &amp;bottom</source>
        <translation>Всегда в&amp;низу</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="709"/>
        <source>&amp;Close</source>
        <translation>&amp;Закрыть</translation>
    </message>
</context>
<context>
    <name>LXQtTaskGroup</name>
    <message>
        <location filename="../lxqttaskgroup.cpp" line="82"/>
        <source>Group</source>
        <translation>Группа</translation>
    </message>
    <message>
        <location filename="../lxqttaskgroup.cpp" line="84"/>
        <source>Close group</source>
        <translation>Закрыть группу</translation>
    </message>
</context>
<context>
    <name>LXQtTaskbarConfiguration</name>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="14"/>
        <source>Task Manager Settings</source>
        <translation>Настройки панели задач</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Общие</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="55"/>
        <source>Show only windows from &amp;panel&apos;s screen</source>
        <translation>Показывать окна только с экрана &amp;панели</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="62"/>
        <source>Show only minimized windows</source>
        <translation>Показывать только свёрнутые окна</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="69"/>
        <source>Raise minimized windows on current desktop</source>
        <translation>Разворачивать свёрнутые окна на текущем рабочем столе</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="49"/>
        <source>Cycle windows on wheel scrolling</source>
        <translation>Переключать окна колёсиком мыши</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="143"/>
        <source>Window &amp;grouping</source>
        <translation>&amp;Группировка окон</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="162"/>
        <source>Appearance</source>
        <translation>Внешний вид</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="181"/>
        <source>Maximum button width</source>
        <translation>Максимальная ширина кнопки</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="125"/>
        <location filename="../lxqttaskbarconfiguration.ui" line="194"/>
        <location filename="../lxqttaskbarconfiguration.ui" line="220"/>
        <source> px</source>
        <translation> пикс</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="207"/>
        <source>Maximum button height</source>
        <translation>Максимальная высота кнопки</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="240"/>
        <source>Use icons by WindowClass, if available</source>
        <translation>Использовать значки WindowClass, если доступно</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="171"/>
        <source>Button style</source>
        <translation>Стиль кнопок</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="43"/>
        <source>Show only windows from desktop</source>
        <translation>Показывать окна только с рабочего стола</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="86"/>
        <source>Mouse Wheel</source>
        <translation>Колёсико мыши</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="112"/>
        <source>Wheel Delta Threshold</source>
        <translation>Порог чувствительности колёсика мыши</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="152"/>
        <source>Show popup on mouse hover</source>
        <translation>Показывать список при наведении мыши</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="233"/>
        <source>Auto&amp;rotate buttons when the panel is vertical</source>
        <translation>Авто&amp;поворот кнопок, когда панель вертикальна</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="76"/>
        <source>Close on middle-click</source>
        <translation>Закрывать по щелчку средней кнопки мыши</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="44"/>
        <source>Icon and text</source>
        <translation>Значок и текст</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="45"/>
        <source>Only icon</source>
        <translation>Только значок</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="46"/>
        <source>Only text</source>
        <translation>Только текст</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="48"/>
        <source>Disabled</source>
        <translation>Нет действий</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="50"/>
        <source>Scroll up to raise, down to minimize</source>
        <translation>Прокрутка вверх разворачивает окно, вниз — сворачивает</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="51"/>
        <source>Scroll up to minimize, down to raise</source>
        <translation>Прокрутка вверх сворачивает окно, вниз — разворачивает</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="53"/>
        <source>Current</source>
        <translation>Текущий</translation>
    </message>
</context>
</TS>

==> lxqt-panel-0.15.1.tar.xz: lxqt-panel-0.15.1/plugin-taskbar/translations/taskbar_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>LXQtTaskBar</name>
    <message>
        <location filename="../lxqttaskbar.cpp" line="655"/>
        <source>Activate task %1</source>
        <translation>Запустить задачу %1</translation>
    </message>
</context>
<context>
    <name>LXQtTaskButton</name>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="635"/>
        <source>Application</source>
        <translation>Приложение</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="669"/>
        <source>To &amp;Desktop</source>
        <translation>&amp;На рабочий стол</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="671"/>
        <source>&amp;All Desktops</source>
        <translation>&amp;Все рабочие столы</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="679"/>
        <source>Desktop &amp;%1</source>
        <translation>Рабочий стол &amp;%1</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="686"/>
        <source>&amp;To Current Desktop</source>
        <translation>На &amp;текущий рабочий стол</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="694"/>
        <source>&amp;Move</source>
        <translation>Пере&amp;местить</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="697"/>
        <source>Resi&amp;ze</source>
        <translation>Изм&amp;енить размер</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="704"/>
        <source>Ma&amp;ximize</source>
        <translation>Р&amp;азвернуть</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="711"/>
        <source>Maximize vertically</source>
        <translation>Развернуть по вертикали</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="716"/>
        <source>Maximize horizontally</source>
        <translation>Развернуть по горизонтали</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="722"/>
        <source>&amp;Restore</source>
        <translation>&amp;Восстановить</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="726"/>
        <source>Mi&amp;nimize</source>
        <translation>&amp;Свернуть</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="732"/>
        <source>Roll down</source>
        <translation>Развернуть из заголовока</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="738"/>
        <source>Roll up</source>
        <translation>Свернуть в заголовок</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="746"/>
        <source>&amp;Layer</source>
        <translation>&amp;Положение</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="748"/>
        <source>Always on &amp;top</source>
        <translation>Всегда на&amp;верху</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="754"/>
        <source>&amp;Normal</source>
        <translation>&amp;Обычное</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="760"/>
        <source>Always on &amp;bottom</source>
        <translation>Всегда в&amp;низу</translation>
    </message>
    <message>
        <location filename="../lxqttaskbutton.cpp" line="768"/>
        <source>&amp;Close</source>
        <translation>&amp;Закрыть</translation>
    </message>
</context>
<context>
    <name>LXQtTaskGroup</name>
    <message>
        <location filename="../lxqttaskgroup.cpp" line="82"/>
        <source>Group</source>
        <translation>Группа</translation>
    </message>
    <message>
        <location filename="../lxqttaskgroup.cpp" line="84"/>
        <source>Close group</source>
        <translation>Закрыть группу</translation>
    </message>
</context>
<context>
    <name>LXQtTaskbarConfiguration</name>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="14"/>
        <source>Task Manager Settings</source>
        <translation>Настройки панели задач</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Общие</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="55"/>
        <source>Show only windows from &amp;panel&apos;s screen</source>
        <translation>Показывать окна только с экрана &amp;панели</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="62"/>
        <source>Show only minimized windows</source>
        <translation>Показывать только свёрнутые окна</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="69"/>
        <source>Raise minimized windows on current desktop</source>
        <translation>Разворачивать свёрнутые окна на текущем рабочем столе</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="49"/>
        <source>Cycle windows on wheel scrolling</source>
        <translation>Переключать окна колёсиком мыши</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="143"/>
        <source>Window &amp;grouping</source>
        <translation>&amp;Группировка окон</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="162"/>
        <source>Appearance</source>
        <translation>Внешний вид</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="181"/>
        <source>Maximum button width</source>
        <translation>Максимальная ширина кнопки</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="125"/>
        <location filename="../lxqttaskbarconfiguration.ui" line="194"/>
        <location filename="../lxqttaskbarconfiguration.ui" line="220"/>
        <source> px</source>
        <translation> пикс</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="207"/>
        <source>Maximum button height</source>
        <translation>Максимальная высота кнопки</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="240"/>
        <source>Use icons by WindowClass, if available</source>
        <translation>Использовать значки WindowClass, если доступно</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="171"/>
        <source>Button style</source>
        <translation>Стиль кнопок</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="43"/>
        <source>Show only windows from desktop</source>
        <translation>Показывать окна только с рабочего стола</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="86"/>
        <source>Mouse Wheel</source>
        <translation>Колёсико мыши</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="112"/>
        <source>Wheel Delta Threshold</source>
        <translation>Порог чувствительности колёсика мыши</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="152"/>
        <source>Show popup on mouse hover</source>
        <translation>Показывать список при наведении мыши</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="233"/>
        <source>Auto&amp;rotate buttons when the panel is vertical</source>
        <translation>Авто&amp;поворот кнопок, когда панель вертикальна</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.ui" line="76"/>
        <source>Close on middle-click</source>
        <translation>Закрывать по щелчку средней кнопки мыши</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="44"/>
        <source>Icon and text</source>
        <translation>Значок и текст</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="45"/>
        <source>Only icon</source>
        <translation>Только значок</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="46"/>
        <source>Only text</source>
        <translation>Только текст</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="48"/>
        <source>Disabled</source>
        <translation>Нет действий</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="50"/>
        <source>Scroll up to raise, down to minimize</source>
        <translation>Прокрутка вверх разворачивает окно, вниз — сворачивает</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="51"/>
        <source>Scroll up to minimize, down to raise</source>
        <translation>Прокрутка вверх сворачивает окно, вниз — разворачивает</translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="52"/>
        <source>Scroll up to move to next desktop, down to previous</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="53"/>
        <source>Scroll up to move to previous desktop, down to next</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqttaskbarconfiguration.cpp" line="55"/>
        <source>Current</source>
        <translation>Текущий</translation>
    </message>
</context>
</TS>
